# Changelog

## 0.1.0-alpha.4 (2025-03-19)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/airtop-ai/airtop-core-sdk-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** api update ([#74](https://github.com/airtop-ai/airtop-core-sdk-python/issues/74)) ([bbeac0c](https://github.com/airtop-ai/airtop-core-sdk-python/commit/bbeac0c8382b7090b1a3b8176f7684a6190f274c))

## 0.1.0-alpha.3 (2025-03-18)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/airtop-ai/airtop-core-sdk-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** api update ([#58](https://github.com/airtop-ai/airtop-core-sdk-python/issues/58)) ([92e7db3](https://github.com/airtop-ai/airtop-core-sdk-python/commit/92e7db3c2e78b5734ebb97c4a18f5c67c8d093e1))
* **api:** api update ([#60](https://github.com/airtop-ai/airtop-core-sdk-python/issues/60)) ([a339c50](https://github.com/airtop-ai/airtop-core-sdk-python/commit/a339c50b2d1761dd73ec13da37b768574f44492e))
* **api:** api update ([#61](https://github.com/airtop-ai/airtop-core-sdk-python/issues/61)) ([e714f85](https://github.com/airtop-ai/airtop-core-sdk-python/commit/e714f85f3d07d8d5513639e62954aca80979b865))
* **api:** api update ([#63](https://github.com/airtop-ai/airtop-core-sdk-python/issues/63)) ([2978e5a](https://github.com/airtop-ai/airtop-core-sdk-python/commit/2978e5acc79d6067da03b78ab1ad17d6d35f56f1))
* **api:** api update ([#68](https://github.com/airtop-ai/airtop-core-sdk-python/issues/68)) ([08d8d98](https://github.com/airtop-ai/airtop-core-sdk-python/commit/08d8d9854fc546cd019fbee2a2ceb9e9a73f6039))
* **api:** api update ([#69](https://github.com/airtop-ai/airtop-core-sdk-python/issues/69)) ([55c6691](https://github.com/airtop-ai/airtop-core-sdk-python/commit/55c6691652619b46f624ad92b7b51f55597fbf1a))
* **api:** api update ([#70](https://github.com/airtop-ai/airtop-core-sdk-python/issues/70)) ([df4ec7e](https://github.com/airtop-ai/airtop-core-sdk-python/commit/df4ec7e5314efc6ebd7a4782987e446b923d6fab))
* **api:** api update ([#71](https://github.com/airtop-ai/airtop-core-sdk-python/issues/71)) ([b352ab7](https://github.com/airtop-ai/airtop-core-sdk-python/commit/b352ab7064972925c6b70f832d0d24f91c0058e9))
* **api:** api update ([#72](https://github.com/airtop-ai/airtop-core-sdk-python/issues/72)) ([7236513](https://github.com/airtop-ai/airtop-core-sdk-python/commit/7236513fe803b01241f1a65b9037fe77dc6dacaa))


### Bug Fixes

* **ci:** ensure pip is always available ([#66](https://github.com/airtop-ai/airtop-core-sdk-python/issues/66)) ([1ed4bb7](https://github.com/airtop-ai/airtop-core-sdk-python/commit/1ed4bb7693e8747ef0e86b332b83e56a63d4e4b2))
* **ci:** remove publishing patch ([#67](https://github.com/airtop-ai/airtop-core-sdk-python/issues/67)) ([18e14df](https://github.com/airtop-ai/airtop-core-sdk-python/commit/18e14df8d5ad19ef13d9c1c54ec4c90c33d9277e))
* **types:** handle more discriminated union shapes ([#65](https://github.com/airtop-ai/airtop-core-sdk-python/issues/65)) ([6560a8b](https://github.com/airtop-ai/airtop-core-sdk-python/commit/6560a8bf890c659947697e528aa1b9118f87982c))


### Chores

* **internal:** bump rye to 0.44.0 ([#64](https://github.com/airtop-ai/airtop-core-sdk-python/issues/64)) ([f972687](https://github.com/airtop-ai/airtop-core-sdk-python/commit/f97268759964f3eb4a5d44ddfde3a4147dd597e9))
* **internal:** remove extra empty newlines ([#62](https://github.com/airtop-ai/airtop-core-sdk-python/issues/62)) ([5949642](https://github.com/airtop-ai/airtop-core-sdk-python/commit/5949642e3a02998e3f4a261829880d92ef717e55))

## 0.1.0-alpha.2 (2025-03-11)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/airtop-ai/airtop-core-sdk-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([#55](https://github.com/airtop-ai/airtop-core-sdk-python/issues/55)) ([78ab705](https://github.com/airtop-ai/airtop-core-sdk-python/commit/78ab7050d9baa7f1d76559583adbdd754cffcd92))

## 0.1.0-alpha.1 (2025-03-11)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/airtop-ai/airtop-core-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([#14](https://github.com/airtop-ai/airtop-core-sdk-python/issues/14)) ([33c37de](https://github.com/airtop-ai/airtop-core-sdk-python/commit/33c37de49dd279e5b146b20bf90354bbaea2b848))
* **api:** api update ([#15](https://github.com/airtop-ai/airtop-core-sdk-python/issues/15)) ([1975458](https://github.com/airtop-ai/airtop-core-sdk-python/commit/19754582cd72d843c8192ec238d9da2da8fa7d1f))
* **api:** api update ([#16](https://github.com/airtop-ai/airtop-core-sdk-python/issues/16)) ([93b5528](https://github.com/airtop-ai/airtop-core-sdk-python/commit/93b5528e6b431526a00c370f5f72d54256202070))
* **api:** api update ([#17](https://github.com/airtop-ai/airtop-core-sdk-python/issues/17)) ([a9026c9](https://github.com/airtop-ai/airtop-core-sdk-python/commit/a9026c98157371e7fd4448c9d12c48eea8660387))
* **api:** api update ([#22](https://github.com/airtop-ai/airtop-core-sdk-python/issues/22)) ([7241dc7](https://github.com/airtop-ai/airtop-core-sdk-python/commit/7241dc7255427091c6b7789c15251d0d811f5768))
* **api:** api update ([#23](https://github.com/airtop-ai/airtop-core-sdk-python/issues/23)) ([8da887b](https://github.com/airtop-ai/airtop-core-sdk-python/commit/8da887b977e4bb61a5579f56b6911dc701cbadcb))
* **api:** api update ([#24](https://github.com/airtop-ai/airtop-core-sdk-python/issues/24)) ([76b084c](https://github.com/airtop-ai/airtop-core-sdk-python/commit/76b084cab9257a526324186e63aac8e8cf1ee2d3))
* **api:** api update ([#27](https://github.com/airtop-ai/airtop-core-sdk-python/issues/27)) ([1530df5](https://github.com/airtop-ai/airtop-core-sdk-python/commit/1530df5df5cf1fed0c613c36bd7ef9906cfa408b))
* **api:** api update ([#28](https://github.com/airtop-ai/airtop-core-sdk-python/issues/28)) ([8fdca9b](https://github.com/airtop-ai/airtop-core-sdk-python/commit/8fdca9b68e9a074282800aa44535808f24100b93))
* **api:** api update ([#29](https://github.com/airtop-ai/airtop-core-sdk-python/issues/29)) ([a8ae7b9](https://github.com/airtop-ai/airtop-core-sdk-python/commit/a8ae7b9ece485068ebc0ca321c2254f2aecbfa6a))
* **api:** api update ([#30](https://github.com/airtop-ai/airtop-core-sdk-python/issues/30)) ([f746a3b](https://github.com/airtop-ai/airtop-core-sdk-python/commit/f746a3b98ad670a6717d585376ff5bee3f7b0384))
* **api:** api update ([#32](https://github.com/airtop-ai/airtop-core-sdk-python/issues/32)) ([5c952b1](https://github.com/airtop-ai/airtop-core-sdk-python/commit/5c952b11a2934ec0990c164260ab6c5a80657082))
* **api:** api update ([#33](https://github.com/airtop-ai/airtop-core-sdk-python/issues/33)) ([01412b3](https://github.com/airtop-ai/airtop-core-sdk-python/commit/01412b33c15c8caf2d842ec4c08284738ac12df3))
* **api:** api update ([#36](https://github.com/airtop-ai/airtop-core-sdk-python/issues/36)) ([53eda14](https://github.com/airtop-ai/airtop-core-sdk-python/commit/53eda14d6270920b980bca8afbe2018078f90d04))
* **api:** api update ([#37](https://github.com/airtop-ai/airtop-core-sdk-python/issues/37)) ([e4e99ec](https://github.com/airtop-ai/airtop-core-sdk-python/commit/e4e99ec92a1116a4e4afe3d36cd76ff514d8fa2a))
* **api:** api update ([#38](https://github.com/airtop-ai/airtop-core-sdk-python/issues/38)) ([23b151b](https://github.com/airtop-ai/airtop-core-sdk-python/commit/23b151b3d902ab8c59a72074357f6f4a10b45d4d))
* **api:** api update ([#39](https://github.com/airtop-ai/airtop-core-sdk-python/issues/39)) ([daaebfc](https://github.com/airtop-ai/airtop-core-sdk-python/commit/daaebfc32b5108dc2ed8027ec98f986b1824d0b4))
* **api:** api update ([#4](https://github.com/airtop-ai/airtop-core-sdk-python/issues/4)) ([23a7455](https://github.com/airtop-ai/airtop-core-sdk-python/commit/23a7455e3620c66bbed08b1fdbaf4c2bbc9cbbdc))
* **api:** api update ([#40](https://github.com/airtop-ai/airtop-core-sdk-python/issues/40)) ([10b8c21](https://github.com/airtop-ai/airtop-core-sdk-python/commit/10b8c21558e53b5e0d4dadaecdeba23039a97c9f))
* **api:** api update ([#42](https://github.com/airtop-ai/airtop-core-sdk-python/issues/42)) ([aa9d15c](https://github.com/airtop-ai/airtop-core-sdk-python/commit/aa9d15c19748d0312f25c19ab4747d2d814b7577))
* **api:** api update ([#43](https://github.com/airtop-ai/airtop-core-sdk-python/issues/43)) ([193a109](https://github.com/airtop-ai/airtop-core-sdk-python/commit/193a109519269a87325eaf5401f990e32aa3a931))
* **api:** api update ([#44](https://github.com/airtop-ai/airtop-core-sdk-python/issues/44)) ([751ab89](https://github.com/airtop-ai/airtop-core-sdk-python/commit/751ab89daef5eba90b483d3f3bae4a1643cead05))
* **api:** api update ([#45](https://github.com/airtop-ai/airtop-core-sdk-python/issues/45)) ([e3ff992](https://github.com/airtop-ai/airtop-core-sdk-python/commit/e3ff992ea5463629430400de49bb52b7da32e3c2))
* **api:** api update ([#46](https://github.com/airtop-ai/airtop-core-sdk-python/issues/46)) ([f50d370](https://github.com/airtop-ai/airtop-core-sdk-python/commit/f50d37028e4d63b23ce26a405ae647955a8bf6c8))
* **api:** api update ([#47](https://github.com/airtop-ai/airtop-core-sdk-python/issues/47)) ([68977a5](https://github.com/airtop-ai/airtop-core-sdk-python/commit/68977a59fb0a17df1feb7284c20626de139bbf35))
* **api:** api update ([#49](https://github.com/airtop-ai/airtop-core-sdk-python/issues/49)) ([df8e513](https://github.com/airtop-ai/airtop-core-sdk-python/commit/df8e513e80a55d67c848025da9bbdfee3600f2c2))
* **api:** api update ([#50](https://github.com/airtop-ai/airtop-core-sdk-python/issues/50)) ([9b4b132](https://github.com/airtop-ai/airtop-core-sdk-python/commit/9b4b13210158e474caafdba1b286b545879ae8ea))
* **api:** manual updates ([#13](https://github.com/airtop-ai/airtop-core-sdk-python/issues/13)) ([7af1bb0](https://github.com/airtop-ai/airtop-core-sdk-python/commit/7af1bb0685c8cd95c398480d28cde73ae95f7562))
* **api:** manual updates ([#18](https://github.com/airtop-ai/airtop-core-sdk-python/issues/18)) ([e65b13b](https://github.com/airtop-ai/airtop-core-sdk-python/commit/e65b13ba234396064a6382ae9715076bd4baee66))
* **api:** manual updates ([#19](https://github.com/airtop-ai/airtop-core-sdk-python/issues/19)) ([142999a](https://github.com/airtop-ai/airtop-core-sdk-python/commit/142999a1f7562bab8a11332da4572bfa732b4bb1))
* **api:** manual updates ([#20](https://github.com/airtop-ai/airtop-core-sdk-python/issues/20)) ([a7f6cf5](https://github.com/airtop-ai/airtop-core-sdk-python/commit/a7f6cf51d213ccb1c1c31f48a96e898c606d04d3))
* **api:** manual updates ([#21](https://github.com/airtop-ai/airtop-core-sdk-python/issues/21)) ([b456e6b](https://github.com/airtop-ai/airtop-core-sdk-python/commit/b456e6b192b40a313efdb12bc89eceba02178743))
* **api:** manual updates ([#5](https://github.com/airtop-ai/airtop-core-sdk-python/issues/5)) ([da08fd3](https://github.com/airtop-ai/airtop-core-sdk-python/commit/da08fd3f29116c78bc959303e1e43ff4996ac166))
* **api:** manual updates ([#6](https://github.com/airtop-ai/airtop-core-sdk-python/issues/6)) ([b6bab8e](https://github.com/airtop-ai/airtop-core-sdk-python/commit/b6bab8e4159f7e2072dc5d8b774c8fc180070130))
* **api:** manual updates ([#7](https://github.com/airtop-ai/airtop-core-sdk-python/issues/7)) ([4a57f87](https://github.com/airtop-ai/airtop-core-sdk-python/commit/4a57f87ba13a82d0a290e0ce7ddb4ace30a4b78e))
* **api:** manual updates ([#8](https://github.com/airtop-ai/airtop-core-sdk-python/issues/8)) ([41b2731](https://github.com/airtop-ai/airtop-core-sdk-python/commit/41b2731798e1830cd365d4b73302bce3553bc0b0))
* **api:** manual updates ([#9](https://github.com/airtop-ai/airtop-core-sdk-python/issues/9)) ([0fc80a9](https://github.com/airtop-ai/airtop-core-sdk-python/commit/0fc80a9b5369068a9bcca68294d172abaf480d83))
* **api:** update via SDK Studio ([6cd68fb](https://github.com/airtop-ai/airtop-core-sdk-python/commit/6cd68fbd305cb7932bf063b2e10d2f730cf92398))
* **api:** update via SDK Studio ([b45f8c3](https://github.com/airtop-ai/airtop-core-sdk-python/commit/b45f8c3520ce3906b3b8db33eae8b5a2b8c6176b))
* **api:** update via SDK Studio ([aee6959](https://github.com/airtop-ai/airtop-core-sdk-python/commit/aee69598233ee9acf128584e6267755542001180))
* **api:** update via SDK Studio ([ec062a2](https://github.com/airtop-ai/airtop-core-sdk-python/commit/ec062a27560e888daad700989b586d57b8a9bd8a))
* **api:** update via SDK Studio ([da71cd1](https://github.com/airtop-ai/airtop-core-sdk-python/commit/da71cd1599505ae52603b8e54d32a5e704955545))
* **api:** update via SDK Studio ([8b5f0b1](https://github.com/airtop-ai/airtop-core-sdk-python/commit/8b5f0b133f47cb49cd9e5635a51b85ac65b5706c))
* **api:** update via SDK Studio ([ff06076](https://github.com/airtop-ai/airtop-core-sdk-python/commit/ff06076bec19a41e89862a0bfc00d8c8d07b51c2))
* **client:** allow passing `NotGiven` for body ([#25](https://github.com/airtop-ai/airtop-core-sdk-python/issues/25)) ([060e057](https://github.com/airtop-ai/airtop-core-sdk-python/commit/060e057cd359ca544317697aa1b201688d262226))


### Bug Fixes

* asyncify on non-asyncio runtimes ([#11](https://github.com/airtop-ai/airtop-core-sdk-python/issues/11)) ([e077906](https://github.com/airtop-ai/airtop-core-sdk-python/commit/e077906e2cfaba3e86a3d4c63fea18718013deab))
* **client:** mark some request bodies as optional ([060e057](https://github.com/airtop-ai/airtop-core-sdk-python/commit/060e057cd359ca544317697aa1b201688d262226))


### Chores

* **docs:** update client docstring ([#35](https://github.com/airtop-ai/airtop-core-sdk-python/issues/35)) ([801b9c5](https://github.com/airtop-ai/airtop-core-sdk-python/commit/801b9c5638190ba867f04c2d39bc45f5b1571e37))
* go live ([#1](https://github.com/airtop-ai/airtop-core-sdk-python/issues/1)) ([627e0cf](https://github.com/airtop-ai/airtop-core-sdk-python/commit/627e0cf711429e6af1d84482db782d807f31ea7b))
* **internal:** codegen related update ([#53](https://github.com/airtop-ai/airtop-core-sdk-python/issues/53)) ([141bddd](https://github.com/airtop-ai/airtop-core-sdk-python/commit/141bddd0fc4c8ab644b289f0a94d2c60f9c07152))
* **internal:** fix devcontainers setup ([#26](https://github.com/airtop-ai/airtop-core-sdk-python/issues/26)) ([20a5250](https://github.com/airtop-ai/airtop-core-sdk-python/commit/20a5250776143c8c719cf15e8ccc4f919ac8496c))
* **internal:** properly set __pydantic_private__ ([#31](https://github.com/airtop-ai/airtop-core-sdk-python/issues/31)) ([2c7bf02](https://github.com/airtop-ai/airtop-core-sdk-python/commit/2c7bf02ca1481a5d186ef82ad604a9471c8ef9dd))
* **internal:** remove unused http client options forwarding ([#41](https://github.com/airtop-ai/airtop-core-sdk-python/issues/41)) ([77c0c89](https://github.com/airtop-ai/airtop-core-sdk-python/commit/77c0c89781436fdb976088dde09f704ad25097b4))
* **internal:** update client tests ([#10](https://github.com/airtop-ai/airtop-core-sdk-python/issues/10)) ([3acac6e](https://github.com/airtop-ai/airtop-core-sdk-python/commit/3acac6edc9d9a712303e174e07c4a3c2d9b4b30c))
* **internal:** update client tests ([#12](https://github.com/airtop-ai/airtop-core-sdk-python/issues/12)) ([80cf3ae](https://github.com/airtop-ai/airtop-core-sdk-python/commit/80cf3ae00a394cc1cb45055bb3db9cde701a5623))
* update SDK settings ([#3](https://github.com/airtop-ai/airtop-core-sdk-python/issues/3)) ([4801947](https://github.com/airtop-ai/airtop-core-sdk-python/commit/4801947cadfba0cdc753f5ff0ef8e5590c957117))
* update SDK settings ([#48](https://github.com/airtop-ai/airtop-core-sdk-python/issues/48)) ([eef1217](https://github.com/airtop-ai/airtop-core-sdk-python/commit/eef1217551d2bcfe6ffb8ca46e833fce38089b95))


### Documentation

* revise readme docs about nested params ([#51](https://github.com/airtop-ai/airtop-core-sdk-python/issues/51)) ([0535420](https://github.com/airtop-ai/airtop-core-sdk-python/commit/05354205558f7005065bad683e4343f193b436e8))
* update URLs from stainlessapi.com to stainless.com ([#34](https://github.com/airtop-ai/airtop-core-sdk-python/issues/34)) ([a63a4f6](https://github.com/airtop-ai/airtop-core-sdk-python/commit/a63a4f649b62a971d41e3f76a5475fe76404e8c4))
